@@ -17,7 +17,7 @@ use HTML::DOM::Node 'DOCUMENT_NODE';
 use Scalar::Util 'weaken';
 use URI;
 
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = 'HTML::DOM::Node';
 
 require    HTML::DOM::Collection;
@@ -45,7 +45,7 @@ HTML::DOM - A Perl implementation of the HTML Document Object Model
 
 =head1 VERSION
 
-Version 0.055 (alpha)
+Version 0.056 (alpha)
 
 B<WARNING:> This module is still at an experimental stage.  The API is 
 subject to change without
@@ -1018,7 +1018,11 @@ sub title {
 	}
 	else {
 		return "" unless @_;
-		$doc->find('head')->appendChild(
+		( $doc->find('head')
+		   || ( $doc->find('html')
+		         || $doc->appendChild($doc->createElement('html'))
+		      )->appendChild($doc->createElement('head'))
+		)->appendChild(
 			my $t = $doc->createElement('title')
 		);
 		$t->text(@_);
@@ -1496,7 +1500,7 @@ object that has one.
 
 Listeners and handlers differ in one important aspect.  A listener has to
 call C<preventDefault> on the event object to cancel the default action.  A
-handler simply returns a defined false value (except for mouseover event,
+handler simply returns a defined false value (except for mouseover events,
 which must return a true value to cancel the default).
 
 =head2 Default Actions
@@ -1616,7 +1620,7 @@ This holds a weak reference.
 =item $tree->event_listeners_enabled( $new_val )
 
 This attribute, which is true by default, can be used to disable event
-handlers and listeners. (Default event handlers [see below] still run, 
+handlers and listeners. (Default event handlers [see above] still run, 
 though.)
 
 =back
@@ -1796,7 +1800,8 @@ Not listed above is L<HTML::DOM::EventTarget>, which is a base class both
 for L<HTML::DOM::Node> and L<HTML::DOM::Attr>. The format I'm using above
 doesn't allow for multiple inheritance, so I probably need to redo it.
 
-HTML::DOM::Node also implements the L<HTML::Element>, but with a few
+HTML::DOM::Node also implements the L<HTML::Element> interface, but with a
+few
 differences. In particular:
 
 =over
@@ -1843,7 +1848,7 @@ lengths are specified in Unicode characters, not in UTF-16 bytes). The
 alternate methods C<length16>, C<substringData16> I<et al.> use UTF-16 for 
 offsets
 and are standards-compliant in that regard (but the string returned by
-C<substringData> is still a regular Perl string).
+C<substringData16> is still a regular Perl string).
 
 =begin for-me
 
@@ -1929,7 +1934,7 @@ B<To report bugs,> please e-mail the author.
 
 =head1 AUTHOR, COPYRIGHT & LICENSE
 
-Copyright (C) 2007-14 Father Chrysostomos
+Copyright (C) 2007-16 Father Chrysostomos
 
   $text = new HTML::DOM ->createTextNode('sprout');
   $text->appendData('@');
