@@ -10,7 +10,7 @@ require HTML::DOM::Element;
 require HTML::DOM::NodeList::Magic;
 #require HTML::DOM::Collection::Elements;
 
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::Element';
 
 use overload fallback => 1,
@@ -382,7 +382,9 @@ sub make_request
 #my $origval = $val;
                 (my $charset, $val) = _apply_charset \@charsets, [$val];
 #use DDS; Dump [$origval,$val, ];
-                push @new_form, Encode'encode('MIME-B',$name),
+                my $enc = $name;
+                $enc = Encode'encode('MIME-B', $enc) if $enc =~ /[^ -~]/;
+                push @new_form, $enc,
                     ref $$val[0] ? $$val[0] : [(undef)x2,
                         Content_Type => "text/plain; charset=\"$charset\"",
                         Content => @$val,
@@ -412,7 +414,7 @@ package HTML::DOM::NodeList::Radio; # solely for HTML::Form compatibility
 use Carp 'croak';
 require HTML::DOM::NodeList;
 
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::NodeList';
 
 sub type { 'radio' }
@@ -484,7 +486,7 @@ use warnings;
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 
 require HTML::DOM::Collection;
 our @ISA = 'HTML::DOM::Collection';
@@ -538,7 +540,7 @@ HTML::DOM::Element::Form - A Perl class for representing 'form' elements in an H
 
 =head1 VERSION
 
-Version 0.055
+Version 0.056
 
 =head1 SYNOPSIS
 
@@ -665,7 +667,7 @@ L<HTML::Form>
 # ------- HTMLSelectElement interface ---------- #
 
 package HTML::DOM::Element::Select;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = 'HTML::DOM::Element';
 
 use overload fallback=>1, '@{}' => sub { shift->options };
@@ -758,7 +760,7 @@ package HTML::DOM::Collection::Options;
 use strict;
 use warnings;
 
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 
 use Carp 'croak';
 use constant sel => 5; # must not conflict with super
@@ -836,7 +838,7 @@ sub length { # override
 # ------- HTMLOptGroupElement interface ---------- #
 
 package HTML::DOM::Element::OptGroup;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = 'HTML::DOM::Element';
 
 sub label  { shift->_attr( label => @_) }
@@ -846,7 +848,7 @@ sub label  { shift->_attr( label => @_) }
 # ------- HTMLOptionElement interface ---------- #
 
 package HTML::DOM::Element::Option;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -959,7 +961,7 @@ sub _reset { delete shift->{_HTML_DOM_sel} }
 # ------- HTMLInputElement interface ---------- #
 
 package HTML::DOM::Element::Input;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -1181,7 +1183,7 @@ sub content {
 # ------- HTMLTextAreaElement interface ---------- #
 
 package HTML::DOM::Element::TextArea;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::Element';
 
 sub defaultValue { # same as HTML::DOM::Element::Title::text
@@ -1229,7 +1231,7 @@ sub _reset {
 # ------- HTMLButtonElement interface ---------- #
 
 package HTML::DOM::Element::Button;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1286,7 +1288,7 @@ sub _reset {}
 # ------- HTMLLabelElement interface ---------- #
 
 package HTML::DOM::Element::Label;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1296,7 +1298,7 @@ sub htmlFor { shift->_attr( for       => @_) }
 # ------- HTMLFieldSetElement interface ---------- #
 
 package HTML::DOM::Element::FieldSet;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1304,7 +1306,7 @@ our @ISA = qw'HTML::DOM::Element';
 # ------- HTMLLegendElement interface ---------- #
 
 package HTML::DOM::Element::Legend;
-our $VERSION = '0.055';
+our $VERSION = '0.056';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
